@@ -13,8 +13,9 @@
 # limitations under the License.
 
 import copy
-from typing import List
+from typing import List, Optional, Any
 from .protocol.property import Property as ProtocolProperty
+from .protocol.message import Message
 
 
 class Property(ProtocolProperty):
@@ -27,7 +28,6 @@ class Property(ProtocolProperty):
     GET = 0
     SET = 1
     ANNO = 2
-    ANNO_STATUS = 3
 
     PROHIBITED = 0
     REQUIRED = 1
@@ -37,10 +37,12 @@ class Property(ProtocolProperty):
     name: str
     size: int
     anno_status: bool
+    object: Optional[Any]
 
     def __init__(self):
         super().__init__()
         self.attrs = [Property.PROHIBITED, Property.PROHIBITED, Property.PROHIBITED, Property.PROHIBITED]
+        self.object = None
 
     def set_attribute(self, typ: int, attr: int):
         self.attrs[typ] = attr
@@ -78,8 +80,30 @@ class Property(ProtocolProperty):
     def is_announce_required(self) -> bool:
         return self.__is_attribute_required(self.attrs[Property.ANNO])
 
-    def is_status_change_required(self) -> bool:
-        return self.__is_attribute_enabled(self.attrs[Property.ANNO_STATUS])
+    def send_message(self, esv: int, data: bytes = bytearray()) -> bool:
+        """Sends a unicast message to the property asynchronously.
+
+
+        Args:
+            esv (int): A service type of ECHONET Lite.
+            data (bytes, optional): : A property data. Defaults to bytearray().
+
+        Returns:
+            bool: True if successful, otherwise False.
+        """
+        return self.object.send_message(esv, [(self.code, data)])
+
+    def post_message(self, esv: int, data: bytes = bytearray()) -> Optional[Message]:
+        """Posts a unicast message to the property and return the response message synchronously.
+
+        Args:
+            esv (int): A service type of ECHONET Lite.
+            data (bytes, optional): A property data. Defaults to bytearray().
+
+        Returns:
+            Optional[Message]: The response message if successful receiving the response message, otherwise None.
+        """
+        return self.object.post_message(esv, [(self.code, data)])
 
     def copy(self):
         return copy.deepcopy(self)
