@@ -12,17 +12,22 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+from typing import Any, Optional
 from .util import Bytes
 from .node import Node
 from .object import Object
 from .node_profile import NodeProfile
 from .message import Message
 
+from typing import Tuple
+
 
 class RemoteNode(Node):
 
-    def __init__(self):
-        super().__init__()
+    controller: Optional[Any]
+
+    def __init__(self, addr: Optional[Tuple[str, int]] = None):
+        super().__init__(addr)
         self.controller = None
 
     def parse_message(self, msg: Message) -> bool:
@@ -44,8 +49,11 @@ class RemoteNode(Node):
         for n in range(instance_count):
             offset = (Object.CODE_SIZE * n) + 1
             code_bytes = prop.data[offset:(offset + Object.CODE_SIZE)]
-            obj = Object()
-            obj.set_code(Bytes.to_int(code_bytes))
+            obj = Object(Bytes.to_int(code_bytes))
             self.add_object(obj)
 
+        # Is the node a general node?
+        if 0 < len(self.objects):
+            self.add_object(Object(0x0EF001))
+
         return True
