@@ -20,9 +20,11 @@ class MulticastServer(Server):
     ADDRESS = '224.0.23.0'
 
     def __init__(self):
-        super(MulticastServer, self).__init__()
+        super().__init__()
 
     def bind(self, ifaddr: str) -> bool:
+        if not super().bind(ifaddr):
+            return False
         self.sock = self.create_udp_socket()
         self.sock.bind(('0.0.0.0', self.port))
         opt = socket.inet_aton(MulticastServer.ADDRESS) + socket.inet_aton(ifaddr)
